@@ -2,7 +2,7 @@ import inspect
 
 from wechatpy.client import WeChatClient as WeChatClient
 from wechatpy.client.base import BaseWeChatClient, _is_api_endpoint
-from wechatpy.enterprise.client import WeChatClient as WecomClient
+from wechatpy.work.client import WeChatClient as WecomClient
 
 from insnail_ai_tools.wechatpy.work import (
     WeChatDepartmentChild,
